ReorderRequestPolicyConfig#
- class tensorrt_llm.llmapi.ReorderRequestPolicyConfig(
- *,
- policy_name: ~typing.Literal['AgentTree'] | None = None,
- policy_args: ~tensorrt_llm.llmapi.llm_args.AgentTreeConfig = <factory>,
Bases:
StrictBaseModelConfiguration for request reordering policy.
- field policy_args: AgentTreeConfig [Optional]#
The arguments of the request reordering policy.
- field policy_name: Literal['AgentTree'] | None = None#
The name of the request reordering policy.
- __init__(**data: Any) None#
Create a new model by parsing and validating input data from keyword arguments.
Raises [ValidationError][pydantic_core.ValidationError] if the input data cannot be validated to form a valid model.
self is explicitly positional-only to allow self as a field name.